@@ -7,6 +7,7 @@ from django.shortcuts import render_to_response
 from django.conf import settings;
 from django.db.models import Q
 from django.core.paginator import *
+from django.views.decorators.csrf import csrf_exempt
 
 from rapidsms.messages.incoming import IncomingMessage
 from rapidsms.messages.outgoing import OutgoingMessage
@@ -14,6 +15,8 @@ from rapidsms.models import Connection
 from djtables import Table, Column
 from djtables.column import DateColumn
 
+from django.core.mail import send_mail
+
 from .models import Message
 from .router import get_router
 
@@ -37,7 +40,7 @@ class SecureForm(forms.Form):
 class MessageForm(SecureForm):
     backend = forms.CharField(max_length=32)
     sender = forms.CharField(max_length=20)
-    message = forms.CharField(max_length=160)
+    message = forms.CharField(max_length=160, required=False)
     echo = forms.BooleanField(required=False)
 
 class OutboxForm(SecureForm):
@@ -69,6 +72,23 @@ def receive(request):
     else:
         return HttpResponse(json.dumps(response))
 
+@csrf_exempt()
+def relaylog(request):
+    """
+    Used by relay apps to send a log of their status.  The send in log is forwarded by email to the
+    system administrators.
+    """
+    password = getattr(settings, "ROUTER_PASSWORD", None)
+
+    if request.method == 'POST' and 'log' in request.REQUEST and 'password' in request.REQUEST and request.REQUEST['password'] == password:
+        send_mail('Relay Log', 
+                  request.REQUEST['log'], 'code@nyaruka.com',
+                  [admin[1] for admin in settings.ADMINS], fail_silently=False)
+
+        return HttpResponse("Log Sent")
+    else:
+        return HttpResponse("Must be POST of [log, password]")
+
 def outbox(request):
     """
     Returns any messages which have been queued to be sent but have no yet been marked
@@ -144,7 +164,7 @@ def console(request):
     queryset = Message.objects.all()
     
     if request.method == 'POST':
-        if request.POST['action'] == 'test':
+        if request.REQUEST['action'] == 'test':
             form = SendForm(request.POST)
             if form.is_valid():
                 backend = "console"
@@ -153,7 +173,7 @@ def console(request):
                                                        form.cleaned_data['text'])
             reply_form = ReplyForm()
             
-        elif request.POST['action'] == 'reply':
+        elif request.REQUEST['action'] == 'reply':
             reply_form = ReplyForm(request.POST)
             if reply_form.is_valid():
                 if Connection.objects.filter(identity=reply_form.cleaned_data['recipient']).count():
@@ -165,22 +185,22 @@ def console(request):
                     reply_form.errors.setdefault('short_description', ErrorList())
                     reply_form.errors['recipient'].append("This number isn't in the system")
 
-        elif request.POST['action'] == 'search':
-            # split on spaces
-            search_form = SearchForm(request.POST)
-            if search_form.is_valid():
-                terms = search_form.cleaned_data['search'].split()
+    if request.REQUEST.get('action', None) == 'search':
+         # split on spaces
+         search_form = SearchForm(request.REQUEST)
+         if search_form.is_valid():
+             terms = search_form.cleaned_data['search'].split()
 
-                if terms:
-                    term = terms[0]
-                    query = (Q(text__icontains=term) | Q(in_response_to__text__icontains=term) | Q(connection__identity__icontains=term))
-                    for term in terms[1:]:
-                        query &= (Q(text__icontains=term) | Q(in_response_to__text__icontains=term) | Q(connection__identity__icontains=term))
+             if terms:
+                 term = terms[0]
+                 query = (Q(text__icontains=term) | Q(in_response_to__text__icontains=term) | Q(connection__identity__icontains=term))
+                 for term in terms[1:]:
+                     query &= (Q(text__icontains=term) | Q(in_response_to__text__icontains=term) | Q(connection__identity__icontains=term))
 
-                    queryset = queryset.filter(query)
+                 queryset = queryset.filter(query)
 
     paginator = Paginator(queryset.order_by('-id'), 20)
-    page = request.GET.get('page')
+    page = request.REQUEST.get('page')
     try:
         messages = paginator.page(page)
     except EmptyPage:
